pub struct DatabaseLoader { /* private fields */ }Expand description
Configures and builds a Database by scanning the filesystem and memory.
Implementations
Sourceimpl DatabaseLoader
impl DatabaseLoader
Sourcepub fn new(
workspace: PathBuf,
paths: Vec<PathBuf>,
includes: Vec<PathBuf>,
excludes: Vec<Exclusion>,
extensions: Vec<String>,
) -> Self
pub fn new( workspace: PathBuf, paths: Vec<PathBuf>, includes: Vec<PathBuf>, excludes: Vec<Exclusion>, extensions: Vec<String>, ) -> Self
Creates a new loader with the given configuration.
Sourcepub fn add_memory_source(
&mut self,
name: &'static str,
contents: &'static str,
file_type: FileType,
)
pub fn add_memory_source( &mut self, name: &'static str, contents: &'static str, file_type: FileType, )
Adds a memory source to the loader.
This allows you to include files that are not on the filesystem but should be part of the database.
Arguments
name- The logical name of the file, typically its path relative to the workspace.contents- The contents of the file as a string.file_type- The type of the file, indicating whether it’s a host file or a vendored file.
Sourcepub fn load(self) -> Result<Database, DatabaseError>
pub fn load(self) -> Result<Database, DatabaseError>
Scans sources according to the configuration and builds a Database.
This is the main entry point that orchestrates the entire loading process.
It returns a Result as some pre-processing, like compiling globs, can fail.