pub struct GlobSettings {
pub case_insensitive: bool,
pub literal_separator: bool,
pub backslash_escape: bool,
pub empty_alternates: bool,
}Expand description
Settings for glob pattern matching behavior.
All defaults match the globset crate defaults for backwards compatibility.
Fields
case_insensitive: boolMatch patterns case-insensitively.
Default: false.
literal_separator: boolWhen true, a single * does not match path separators (/).
This makes src/*/Test match only src/foo/Test, not src/foo/bar/Test.
Use ** for recursive matching.
Default: false.
backslash_escape: boolWhether \ escapes special characters in patterns.
Default: true.
empty_alternates: boolWhether an empty case in alternates is allowed (e.g., {,a} matches "" and "a").
Default: false.